Pongo a los eito, porque en toda esta parte Arashi brilla por su ausencia (a excepción del Riida). Puede que penséis que este capítulo es solo una excusa barata para poner un montón de fotos de Kanjanis descamisados pero...etto...bueno... leedlo, no se me ocurren excusas buenas ahora. :p
-Zel: Te juro que no es lo que parece, Shin-chan.
-Hina: Pos a mí me palece lo que le estalá paleciendo a todo el mundo que vea la tele ahola o se comple la rivista, que os estabais metiendo mano en el palque, y luego con el calentón fuisteis a follal a un love hotel, ¿deshou?
-Zel: Noooo, no es nada de eso niega muy alterada.
-Hina: Me da mal lollo todo esto, polque plimero tienes unos líos mu ralos con Shibuyan, pelo tu novio es Satoshi, y me cae bien, no quielo que le engañes. Y aunque al plincipio me se hizo complicao de vivil contigo cuando me entelé de que eras tan gayer, pos bueno, ahola ya no me estaba impoltando, pelo esto me palece demasiao. Plimelo Baru y ahora Yoko. ¡Esto está mal!
-Zel : Te aseguro que yo no he engañado a Ohno durante todo este tiempo, y mucho menos con Yoko. ¡De verdad que no!
-Hina: Pos es que las fotos están ahí, que le estabas tocando todo a Yokocho... ¿O me vas a dicil que no? Qué desagladable, cleo que necesito tiempo para hacelme a la idea de que todos mis amigos se están volviendo maliquitas pol tu culpa...

Murakami se sienta en el sofá y se pone pensativo mirando fijamente la tele que no deja de dar la coña con las mismas imágenes una y otra vez.
-Zel: Que es todo un malentendido, en la revista se equivocan, y en la tele, y todo el mundo!! Esto es una pesadilla.
-Hina (cambiando de tema, porque esto ya le supera): Pol cielto, te he lavao el moñeco que te regaló Shibuyan, está secándose en el balcón, y te he hacido el desayuno, lo tienes en la mesa. Cómetelo y vístete, que hay que il al tlabajo. Bueno, eso si consigues salil de casa, polque igual s'an ponido los piliodistas ahí abajo pala pleguntalte cosas...
-Zel: Nooo, yo no voy a trabajar, todo el mundo me va a mirar, se pensarán que Yoko y yo... ¡PUAG QUE ASCO! Es que no quiero ni decirlo.
-Hina: Pos dicirlo no lo dilas, pelo haserlo...
-Zel: Te digo que no ha pasado nada de eso, no hemos hecho nada. Anoche solo estuvimos hablando en un parque de Shibuya, pero nos dimos cuenta de que un hombre que no conocíamos nos estaba mirando.
-Hina: ¿Un pelveltido? ¿Un fan de la Johnnys?
-Zel: No, un paparazzi, el tío que sacó ESAS FOTOS, NO HAY DUDA -señala a la tele.- Por todos los Kamisamas, ¿cuándo van a dejar de hablar de esto en el programa?
-Hina: Posiblementle hablen casi todo el día, tas liblao polque mañana saca single nuevo Kattun y ya hablalán de otla cosa...
-Zel: Nadie va a creerme si digo que todo es un malentendido, ¿verdad?
-Hina: Pos no, si ni siquiela yo te estoy cleyendo... -dice escéptico mientras se encoje de hombros.
-Zel: ¿Qué no me crees? -Pregunta indignada. -¿Pero cómo se va a enrollar Yoko con un chico? ¿Tú lo has pensado bien?
-Hina: Pos...homble, no le pega muncho, pelo... yo ya no sé nada, ¡mila Subaru! Bien que anda detlás tuyo, tú sablás lo que le das y lo que le has hecho... pol favol, no entles en detalles, no quielo de sabel nada de vuestlos asuntos sucios -se tapa los oídos con las manos.
-Zel: Subaru es un pervertido, y por probar haría cualquier cosa, ¡NO CUENTA! -Se sienta de un bote junto a Murakami en el sofá y le agarra por la chaquetilla del pijama con cara de desesperación. -Tienes que creerme Shingo, eres mi mejor amigo, si tú no me crees, nadie lo hará.
-Hina: Estás mu serca, quítate, podlias homosexualizalme como a Baru y Yoko, tienes un gran podel homogayer. -Aparta a Zel, mientras pone cara de susto.
-Zel: No seas baka, ser gay no se transmite, no es una enfermedad.
-Hina: ¿Estás segulo de eso?
-Zel: ¡Pues claro! Y Yoko de gay no tiene nada, anoche intentamos huir del paparazzi, Yoko dijo que nos metiéramos en algún sitio con gente, y allí nos separábamos, pero me equivoqué e hice que nos metiéramos en un love hotel... Las luces eran muy bonitas y no leí el cartel, ¿vale? -se justifica.
-Hina: Pos a mí me palece lo que le estalá paleciendo a todo el mundo que vea la tele ahola o se comple la rivista, que os estabais metiendo mano en el palque, y luego con el calentón fuisteis a follal a un love hotel, ¿deshou?
-Zel: Noooo, no es nada de eso niega muy alterada.
-Hina: Me da mal lollo todo esto, polque plimero tienes unos líos mu ralos con Shibuyan, pelo tu novio es Satoshi, y me cae bien, no quielo que le engañes. Y aunque al plincipio me se hizo complicao de vivil contigo cuando me entelé de que eras tan gayer, pos bueno, ahola ya no me estaba impoltando, pelo esto me palece demasiao. Plimelo Baru y ahora Yoko. ¡Esto está mal!
-Zel : Te aseguro que yo no he engañado a Ohno durante todo este tiempo, y mucho menos con Yoko. ¡De verdad que no!
-Hina: Pos es que las fotos están ahí, que le estabas tocando todo a Yokocho... ¿O me vas a dicil que no? Qué desagladable, cleo que necesito tiempo para hacelme a la idea de que todos mis amigos se están volviendo maliquitas pol tu culpa...

Murakami se sienta en el sofá y se pone pensativo mirando fijamente la tele que no deja de dar la coña con las mismas imágenes una y otra vez.
-Zel: Que es todo un malentendido, en la revista se equivocan, y en la tele, y todo el mundo!! Esto es una pesadilla.
-Hina (cambiando de tema, porque esto ya le supera): Pol cielto, te he lavao el moñeco que te regaló Shibuyan, está secándose en el balcón, y te he hacido el desayuno, lo tienes en la mesa. Cómetelo y vístete, que hay que il al tlabajo. Bueno, eso si consigues salil de casa, polque igual s'an ponido los piliodistas ahí abajo pala pleguntalte cosas...
-Zel: Nooo, yo no voy a trabajar, todo el mundo me va a mirar, se pensarán que Yoko y yo... ¡PUAG QUE ASCO! Es que no quiero ni decirlo.
-Hina: Pos dicirlo no lo dilas, pelo haserlo...
-Zel: Te digo que no ha pasado nada de eso, no hemos hecho nada. Anoche solo estuvimos hablando en un parque de Shibuya, pero nos dimos cuenta de que un hombre que no conocíamos nos estaba mirando.
-Hina: ¿Un pelveltido? ¿Un fan de la Johnnys?
-Zel: No, un paparazzi, el tío que sacó ESAS FOTOS, NO HAY DUDA -señala a la tele.- Por todos los Kamisamas, ¿cuándo van a dejar de hablar de esto en el programa?
-Hina: Posiblementle hablen casi todo el día, tas liblao polque mañana saca single nuevo Kattun y ya hablalán de otla cosa...
-Zel: Nadie va a creerme si digo que todo es un malentendido, ¿verdad?
-Hina: Pos no, si ni siquiela yo te estoy cleyendo... -dice escéptico mientras se encoje de hombros.
-Zel: ¿Qué no me crees? -Pregunta indignada. -¿Pero cómo se va a enrollar Yoko con un chico? ¿Tú lo has pensado bien?
-Hina: Pos...homble, no le pega muncho, pelo... yo ya no sé nada, ¡mila Subaru! Bien que anda detlás tuyo, tú sablás lo que le das y lo que le has hecho... pol favol, no entles en detalles, no quielo de sabel nada de vuestlos asuntos sucios -se tapa los oídos con las manos.
-Zel: Subaru es un pervertido, y por probar haría cualquier cosa, ¡NO CUENTA! -Se sienta de un bote junto a Murakami en el sofá y le agarra por la chaquetilla del pijama con cara de desesperación. -Tienes que creerme Shingo, eres mi mejor amigo, si tú no me crees, nadie lo hará.
-Hina: Estás mu serca, quítate, podlias homosexualizalme como a Baru y Yoko, tienes un gran podel homogayer. -Aparta a Zel, mientras pone cara de susto.
-Zel: No seas baka, ser gay no se transmite, no es una enfermedad.
-Hina: ¿Estás segulo de eso?
-Zel: ¡Pues claro! Y Yoko de gay no tiene nada, anoche intentamos huir del paparazzi, Yoko dijo que nos metiéramos en algún sitio con gente, y allí nos separábamos, pero me equivoqué e hice que nos metiéramos en un love hotel... Las luces eran muy bonitas y no leí el cartel, ¿vale? -se justifica.
Murakami, que escuchaba atentamente el relato de Zel
de pronto estalla en carcajadas, se ríe tanto que se le saltan las lágrimas,
hasta aplaude varias veces medio desternillado sobre el sofá. Zel le mira sin
saber qué hacer, el ataque de risa era la última cosa con la que contaba como
posible reacción de su compañero de piso. Se está riendo tanto que teme que se
vaya a mear encima o algo... Por fin, Hina recupera más o menos la compostura,
se seca las lágrimas mientras aún se le escapa un poco la risita mostrando sus
dientones.
-Hina: Es la bakada más enolme que he oído nunca, supongamos que fuela cielto, desde luego Yoko y tú tenéis LA PEOL SUELTE DEL PLANETA.
-Zel: No te niego lo de la mala suerte pero... ¡ES LA VERDAD! Ocurrió así, llámale y pregúntaselo si no me crees -le dice mirándole fijamente.
-Hina: Espela un momento -toma su teléfono y abre el LINE. Hay varios mensajes sin leer en el chat que tiene con el resto de eito.- ¡HUY, 156 MENSAJES! No había tantos aquí desde que Ryo-chan tuvo aquel escándalo de que un señor bolacho le había lamido un pezón en una fiesta.
-Zel: ¿Qué dicen? -pregunta impaciente.
-Hina: Es la bakada más enolme que he oído nunca, supongamos que fuela cielto, desde luego Yoko y tú tenéis LA PEOL SUELTE DEL PLANETA.
-Zel: No te niego lo de la mala suerte pero... ¡ES LA VERDAD! Ocurrió así, llámale y pregúntaselo si no me crees -le dice mirándole fijamente.
-Hina: Espela un momento -toma su teléfono y abre el LINE. Hay varios mensajes sin leer en el chat que tiene con el resto de eito.- ¡HUY, 156 MENSAJES! No había tantos aquí desde que Ryo-chan tuvo aquel escándalo de que un señor bolacho le había lamido un pezón en una fiesta.
-Zel: ¿Qué dicen? -pregunta impaciente.
Murakami le hace un gesto con la mano para que espere
mientras lee la conversación, tiene una extraña sonrisita en la cara y a ratos
se le escapa alguna carcajada.
-Hina: Pos casi todos los mensajes son de Yoko... hay como 100 seguidos diciendo que no es gayer, que no les gustan los hombres, y tú mucho menos. Que ha sido un malentendío, que lo de la tele es mentila y tú eles muy baka.
-Zel: ¿Ahora yo soy baka? Es su culpa, él me llamó anoche para que fuera a verle, si no me llama no hubiera pasado nada de esto. ¡Si yo soy baka él es aún más imbécil! -Grita cabreada.
-Hina: Le diré lo que has dicido.
-Zel: No, no se lo digas!! -Le agarra la mano para que no escriba.
-Hina: ¿Pol que no? Si tienes muncha lazón, encima que te hace il a esa holas a la calle, que luego no me duelmes nada y me pongo mu nelvioso por si te ha pasao algo pol el camino... Le voy a riñir por ilesponsable.
-Zel: Noooo, que luego se enfada conmigo. Bueno... creo que ya lo está desde anoche. Solo tardamos un minuto en salir del love hotel, pero Yoko se cabreó mucho conmigo.
-Hina: ¿Un minuto? ¡En la tele no han dicido nada, están ocultando infolmación! Solo han dicido que "después de un lato salisteis del hotel"
-Zel: Un rato no, ¡fue un minuto, dos como mucho!
-Hina: Pos casi mejol que no lo digan, polque encima de gayers habrían dicido también que elais "eyaculadoles plecozes" o alguna cosa así y pol eso habíais taldado tan poco en acabal.
-Zel: ¿Cómoooo? -Grita confusa.
-Hina: Tenemos muchos haters en la plensa, se dedican a intental destruil la vida de los Johnnys. ¿Aún no te has dao cuenta? Se inventan escándalos que no son, o los exagelan como una montaña aunque solo sea una tontelía...
-Zel: Me he dado cuenta, cada vez que salgo en la tv se monta un escándalo. Mira el otro día cuando dijeron que odiaba a la gente del Kansai.
-Hina: Pues ahola te los follas en un love hotel -dice con una cara muy seria.
-Zel: Que no me he follao a Yoko, ya basta -dice cabreada.
-Hina: Pos tú te lo pieldes, polque es la mejol polla del grupo -suelta a bocajarro.
-Zel: ¿EHHHHHHHHHHHHHHHHH? -Zel tiene tan abiertos los ojos que parece que se le van a salir o algo. -Pero qué dices, la mejor polla de Eito eres tú, que te he visto desnudo muchas veces, más de las necesarias... Tú estás muy bien "de ahí abajo" -reconoce poniéndose colorada.- Que tampoco es que te lo esté mirando siempre ¿ne? Es que como vas desnudo por la casa...
-Hina: Pos casi todos los mensajes son de Yoko... hay como 100 seguidos diciendo que no es gayer, que no les gustan los hombres, y tú mucho menos. Que ha sido un malentendío, que lo de la tele es mentila y tú eles muy baka.
-Zel: ¿Ahora yo soy baka? Es su culpa, él me llamó anoche para que fuera a verle, si no me llama no hubiera pasado nada de esto. ¡Si yo soy baka él es aún más imbécil! -Grita cabreada.
-Hina: Le diré lo que has dicido.
-Zel: No, no se lo digas!! -Le agarra la mano para que no escriba.
-Hina: ¿Pol que no? Si tienes muncha lazón, encima que te hace il a esa holas a la calle, que luego no me duelmes nada y me pongo mu nelvioso por si te ha pasao algo pol el camino... Le voy a riñir por ilesponsable.
-Zel: Noooo, que luego se enfada conmigo. Bueno... creo que ya lo está desde anoche. Solo tardamos un minuto en salir del love hotel, pero Yoko se cabreó mucho conmigo.
-Hina: ¿Un minuto? ¡En la tele no han dicido nada, están ocultando infolmación! Solo han dicido que "después de un lato salisteis del hotel"
-Zel: Un rato no, ¡fue un minuto, dos como mucho!
-Hina: Pos casi mejol que no lo digan, polque encima de gayers habrían dicido también que elais "eyaculadoles plecozes" o alguna cosa así y pol eso habíais taldado tan poco en acabal.
-Zel: ¿Cómoooo? -Grita confusa.
-Hina: Tenemos muchos haters en la plensa, se dedican a intental destruil la vida de los Johnnys. ¿Aún no te has dao cuenta? Se inventan escándalos que no son, o los exagelan como una montaña aunque solo sea una tontelía...
-Zel: Me he dado cuenta, cada vez que salgo en la tv se monta un escándalo. Mira el otro día cuando dijeron que odiaba a la gente del Kansai.
-Hina: Pues ahola te los follas en un love hotel -dice con una cara muy seria.
-Zel: Que no me he follao a Yoko, ya basta -dice cabreada.
-Hina: Pos tú te lo pieldes, polque es la mejol polla del grupo -suelta a bocajarro.
-Zel: ¿EHHHHHHHHHHHHHHHHH? -Zel tiene tan abiertos los ojos que parece que se le van a salir o algo. -Pero qué dices, la mejor polla de Eito eres tú, que te he visto desnudo muchas veces, más de las necesarias... Tú estás muy bien "de ahí abajo" -reconoce poniéndose colorada.- Que tampoco es que te lo esté mirando siempre ¿ne? Es que como vas desnudo por la casa...
Murakami
niega con la cabeza en silencio.
-Hina: Te equivocas, yo solo soy el segundo del grupo.
-Zel: ¿De verdad? ¿Hay alguien que aún la tiene más grande que tú en Kanjani?
-Pregunta asombrada.- Pues... nunca lo hubiera dicho. Y desde luego NUNCA
hubiera pensado en que era Yokoyama-senpai, hubiera dicho cualquier otro antes
que él...-piensa un segundo- Por lógica Okura que es el más alto... o Ryo, o Yasu, sí,
creo que hubiera dicho Yasu. Aunque no sé por qué... ¡Omoshiroi! -Zel ya está
fantaseando demasiado sobre pollas y cerdadas.
-Hina: Te equivocas, yo solo soy el segundo del grupo.
-Zel: ¿De verdad? ¿Hay alguien que aún la tiene más grande que tú en Kanjani?
-Pregunta asombrada.- Pues... nunca lo hubiera dicho. Y desde luego NUNCA
hubiera pensado en que era Yokoyama-senpai, hubiera dicho cualquier otro antes
que él...-piensa un segundo- Por lógica Okura que es el más alto... o Ryo, o Yasu, sí,
creo que hubiera dicho Yasu. Aunque no sé por qué... ¡Omoshiroi! -Zel ya está
fantaseando demasiado sobre pollas y cerdadas.
Murakami
mira a Zel inquisitivo durante unos segundos.
-Hina: Zel-kun , tú no te has acostao con Yoko -dice como llegando a una conclusión.
-Zel: ¿Qué? Pero si ya te he dicho antes que no.
-Hina: Ya... pelo es que no te había cleído.
-Zel: ¿EEEEH? Si Yoko tb te ha escrito en LINE para decir que no había pasado nada de lo que dice la tele.
-Hina: Bueno, pelo es que a él tampoco le he cleído. Si estáis liados, lo ibais a negar, es evidente. Nunca me hubielas dicho que sí te lo has tilado.
-Zel: Te he dicho que no, porque es que NO -contesta enfadada.- No te he mentido.
-Hina: Tenía que asegulalme antes de cleel en tu palabla. Así que te dicido eso pa vel qué me contestabas. Si hubielais follao anoche, me hubielas dicido directamente que ni de coña Yoko la tiene más grande que yo, que ela un mintiloso.
-Zel: ¡Menudo farol! No estamos jugando al póker, eres lo peor. Entonces "tú eres el más grande", ¿neee?
-Hina: No, lo de que soy el segundo es sielto, solo que el plimelo no es Yoko.
-Zel: Me has creado falsas expectativas de chinkos... eso no se hace. Hum...el primero es Yasu ¿verdad? ¡Dímelo kudasai! -Grita cada vez más interesada en el asunto (que por otro lado, ni le va ni le viene).
-Hina: No te voy a dicil quién es. Es un secleto. ¡Hisimos un pacto en el glupo!
-Zel (echándose encima de Hina en el sofá): Pues te convertiré en gay.
-Hina: ¡AY QUITA, NO TE ACELQUES! -empuja a Zel de malos modos y se levanta de un salto del sofá.
-Zel: Qué baka eres. Me voy a desayunar -se levanta ella también del sofá y va sentarse a la mesa donde le espera su desayuno.
Murakami sigue viendo un poco la noticia del supuesto
idilio gayer entre Zel y Yoko. Después se acerca a Zel que está comiendo una
tostada y unos trozos de fruta que Hina amablemente le ha dejado cortados en un
platito.
-Hina: Espelo que esto no afecte al glupo, solo falta que pol que digan en la tele que Yokocho "es gayer" nos dejen de apoyal los fans o caigan las ventas. Si aún no han descubielto que Maru y Yasu son novios.
-Zel: Es verdad, y en cuanto a los Tegomasuzel... la verdad es que en mi grupo gracias al último escándalo hasta vendimos más singles. Fue una sorpresa.
-Hina: No sé qué pasalá, estoy asustao -Mira a Zel con cara de que "no hay papel higiénico".
-Zel: No te preocupes, si es necesario Yoko y yo contaremos la verdad en la tele. Todo saldrá bien, Shin-chan.
-Hina: Eso espelo... sabes qué, en el fondo tiene glasia, Yoko siemple está insinuando a los demás del grupo que si somos gayers y se ríe de nosotlos en la tele y en los consieltos, pos ahola le ha pasao a él. Segulo que no le hase tanta risa.
-Zel: Le ha explotado en toda su cara de alpaca. Es el karma -sentencia.- Lo cierto es que anoche me llamó para chantajearme.
-Hina: ¿Chantaje? ¿Soble qué? ¡No se trata así a los kouhais! ¡Ahola sí que le palto la cala!
-Zel: No hace falta que le pegues. En cuanto a lo otro, no puedo contarte lo del chantaje, es un asunto privado -contesta muy seria.
-Hina: Tú encima no le defiendas, ha sido un niño malo y ahola estáis metidos en este lío.
-Zel: Lo vamos a arreglar, solo espero que él haya aprendido la lección.
-Hina: Más le hasía falta, que se vea bien jodido, así a lo mejol dejaba de putealnos al resto.
-Zel: Huy Hina, eso suena muy vengativo.
-Hina: Si pudiela le daba un escalmiento -confiesa de pronto en un arranque de sinceridad.
-Zel: Shingo, no conocía esa faceta tuya tan malvada... me gusta.
-Hina: Lo sielto es que he quelido gastal una bloma a Yoko desde que me hiso lo del anunsio del babun, ¿sabes que fue todo idea suya? A veses es peol que un demoño. Solo que no me se ha ocurrío nada aún pala podel reilme de él. Soy malo pa estas cosas de hacel putadas... No tengo imaginashión.
-Zel: Dame un momento, creo que tengo una idea...-sonríe con una mueca malvada.
-Hina (asombrado): Huy, esa sonlisa pelvelsa se la he visto a Yoko munchas veses, cuando se le ocule algo malévolo.
-Zel: Creo que ya lo tengo... ¿Cómo de buen actor eres, Shin-chan?
-Hina: Homble... cleo que me defiendo.
-Zel: Necesito que estés de Oscar. Y sobre todo que no se te escape la risa ¿A qué hora vais a estar ensayando hoy por la mañana?
-Hina: De 9,30 a 12,30, luego palamos para comel, que si no Okura se nos pone enfadao y no hay quien le aguante cuando tiene hamble. Solo sabe quejalse, bueno, cuando no tiene hamble también se queja muncho.
-Zel: Acércate, que te lo explico.
-Hina: Vale, pero no me toques ni me homosexualices.
Zel mira a Murakami con cara de querer golpearle.
Más tarde. En el edificio donde ensayan los Johnnys...
![]() |
| Hina for your consideration |
-Yasu(dibujando en un cuadernillo): Mirad, algo como
esto, ¿qué os parece? -Les enseña el diseño de ropa que se le ha ocurrido,
hasta lo ha pintado con unos rotuladores, es hortera a más no poder, con unos
colores que dañan la vista.
Todos asienten encantados y le dan el visto bueno,
Subaru alaba el gusto de Yasu a la hora de escoger colores y estampados
"que combinan tan bien", Maruyama pregunta si a su traje se le pueden
pegar algunas plumas de pavo real en los hombros, y tachuelas metálicas en las
solapas de la chaqueta porque si no se le hace demasiado simple. A Yasu le
encanta la idea y añade rápidamente las plumas al dibujo para ver el efecto. No
pueden negar que son del Kansai.
Hina (sin camiseta y con una toalla atada en la
cabeza, como siempre), está un poco apartado del grupo, se acerca al banco
donde está su bolsa y agarra el móvil, manda un mensaje a Zel preguntando dónde
demonios está. Se está impacientando un poco, en un rato se van a ir de allí y
su compañero de piso aún no ha aparecido a montar "la función de
teatro".
No pasa ni un minuto que Hina ha guardado el móvil cuando
Zel abre violentamente la puerta del cuarto de ensayo con una seguridad en sí
misma que nunca antes había tenido. Da un par de pasos dentro, cierra con un sonoro
portazo y le guiña un ojo a Yoko mientras le sonríe. Yokoyama por un momento se
queda sin habla y con la boca abierta como un tonto. No esperaba ver a Zel por
allí esa mañana, y tampoco es que tuviera muchas ganas de verla después de todo
el lío de la noche anterior...
Zel saluda al resto con un movimiento de cabeza y un
"otsukaresamadesu" rápido.
-Subaru: Omaeee, anoche qué estabas haciendo con...-
suelta un poco desconfiado.-Zel: Ahora no Shibutani -le corta mientras le hace un gesto con la mano para que se calle.
-Subaru: ¿Así es como me tratas? -pregunta forzando el acento de Osaka mientras mira a Zel con aires de superioridad.
Zelgadiss
ignora por completo a Shibutani y se lanza a por su objetivo.
-Zel: Yokoyama-senpai, siento mucho lo de anoche... -empieza.
-Yoko: Bueno, al menos te disculpas, aho -dice un tanto mosqueado.- Es un comienzo.
-Zel: Senpai, ¿cómo está su trasero? ¿Aún le duele?
-Yoko: No, ya estoy mejor, hasta me puedo sentar.
-Yoko: Bueno, al menos te disculpas, aho -dice un tanto mosqueado.- Es un comienzo.
-Zel: Senpai, ¿cómo está su trasero? ¿Aún le duele?
-Yoko: No, ya estoy mejor, hasta me puedo sentar.
Se oye un "ehhhhhh" del resto del grupo.
Comienzan a murmurar cosas entre ellos y a mirarse extrañados .
-Yoko: ¡Oooi, vosotros! -les grita.- Lo pregunta por
qué ayer me caí en el suelo. No empecéis a pensar cosas raras, que sois unos
pervertidos muy degenerados.
-Zel: Senpai... no hace falta que lo ocultemos delante de ellos, ¿ne? En la tele y las revistas tenemos que negarlo, pero...-señala al resto de eito- ellos son sus amigos. ¿No cree que merecen saberlo?
-Yoko (poniéndose nervioso): Zel-kun, no te pillo...
-Zel: No se haga el baka ahora, anoche era menos tímido en el hotel, neee senpai -se acerca a él y con un rápido movimiento le posa la mano en el trasero echándole mucha jeta al asunto.
-Zel: Senpai... no hace falta que lo ocultemos delante de ellos, ¿ne? En la tele y las revistas tenemos que negarlo, pero...-señala al resto de eito- ellos son sus amigos. ¿No cree que merecen saberlo?
-Yoko (poniéndose nervioso): Zel-kun, no te pillo...
-Zel: No se haga el baka ahora, anoche era menos tímido en el hotel, neee senpai -se acerca a él y con un rápido movimiento le posa la mano en el trasero echándole mucha jeta al asunto.
Los kanjani alucinan. Yoko se asusta mucho y se aparta
de ella.
-Yoko: Pe..pe... pero ¿qué haces? -Pregunta
sonrojándose. -¿Estás mal de la cabeza?
-Yasu: ¡YABAI! -Grita como una fan acalorada y frenética en medio de un concierto. Por alguna razón desconocida parece muy feliz de verles juntos en esa escena.
-Zel: Venga senpai, que no pasa nada, seguro que todos ellos ya sospechaban que a usted le iban los chicos.
-Yasu: ¡YABAI! -Grita como una fan acalorada y frenética en medio de un concierto. Por alguna razón desconocida parece muy feliz de verles juntos en esa escena.
-Zel: Venga senpai, que no pasa nada, seguro que todos ellos ya sospechaban que a usted le iban los chicos.
Maruyama suelta un gritito mariquita y de pronto se
pone a hacer flexiones en el suelo a cuento de nada (sus reacciones siempre son
muy imprevisibles).
-Yoko: Pero qué mierdas dices, ¡yo no soy gay! -Le
grita.- ¡NO LO SOY!
Yokoyama mira al resto como buscando que alguien le dé
la razón.
-Hina (interviniendo por fin): Pos...eso explicalía munchas cosas, naaaa. Que siempre andas diciéndonos al resto que somos gayers y blomas de esas, pero tu eles mu sospechoso, y te da pol besalnos y esas cosas.
-Yoko: ¿Que yo soy sospechoso? -le da la risa floja. -No digas tonterías, Hina.
-Hina: Yo solo he dicido lo que pensamos todos, ¿veldad? -mira al resto.
-Hina (interviniendo por fin): Pos...eso explicalía munchas cosas, naaaa. Que siempre andas diciéndonos al resto que somos gayers y blomas de esas, pero tu eles mu sospechoso, y te da pol besalnos y esas cosas.
-Yoko: ¿Que yo soy sospechoso? -le da la risa floja. -No digas tonterías, Hina.
-Hina: Yo solo he dicido lo que pensamos todos, ¿veldad? -mira al resto.
Nadie lo afirma abiertamente, pero se oyen más
murmullos de sospecha.
-Okura: Quién sabe, cosas más raras se han visto... -contesta de pronto en voz baja, y va a sentarse a una silla cercana para seguir contemplando el espectáculo. Está cansado (como siempre).
-Okura: Quién sabe, cosas más raras se han visto... -contesta de pronto en voz baja, y va a sentarse a una silla cercana para seguir contemplando el espectáculo. Está cansado (como siempre).
Ryo tiene su sonrisa socarrona de serie funcionando a
toda mecha y mira a Yoko disfrutando un poco del mal rato ajeno, a Ryo le van
estos rollos. Subaru por su parte, sabe a ciencia cierta que no es posible que
Yoko sea gay y mucho menos por liarse con Zel, que sabe de sobra que es una
chica. Lo que le quema por dentro es saber si realmente pasó "algo"
la noche anterior entre ellos, porque en las fotos de la Friday parecían
demasiado "cercanos" para una quedada nocturna de
"senpai-kouhai". A ver si está peleándose con Satoshi para quitarle a
Zel y de mientras que anda haciendo el imbécil, ella se larga con Yoko y les
deja a los dos con cara de gilipollas. Porque ya sería lo último que le
faltaba.
-Yoko: Nada de eso, no digáis tonterías. Maruyama,
¿quieres dejar de hacer flexiones? Me estás poniendo nervioso.
-Maru: No puedo, hay mucha tensión en el ambiente.
-Ryo: Debe ser por la homosexualidad de Yoko, que al fin ha sido destapada -dice muy seriamente, no obstante Ryo es buen actor.
-Maru: No puedo, hay mucha tensión en el ambiente.
-Ryo: Debe ser por la homosexualidad de Yoko, que al fin ha sido destapada -dice muy seriamente, no obstante Ryo es buen actor.
Hina asiente con la cabeza intentando con todas sus
fuerzas no reírse y joderlo todo.
-Yasu: ¡KYAAAAA! -Grita aún más entusiasmado.
-Yoko (alucinando): ¿OS HABÉIS VUELTO TODOS LOCOS? Ya os expliqué antes por LINE lo que pasó anoche.
-Hina: Bueno, eso es tu velsión, pelo en la rivista palecía otra cosa, ¿na?
-Okura: A ver, si te han pillado, te han pillado.Ya nos inventaremos la manera de arreglarlo y que no afecte al grupo. Pero al menos a nosotros no nos mientas.
-Ryo: Se dice que sois solo amigos, como se ha hecho siempre en la Johnnys. No pasará nada.
-Yasu: ¡KYAAAAA! -Grita aún más entusiasmado.
-Yoko (alucinando): ¿OS HABÉIS VUELTO TODOS LOCOS? Ya os expliqué antes por LINE lo que pasó anoche.
-Hina: Bueno, eso es tu velsión, pelo en la rivista palecía otra cosa, ¿na?
-Okura: A ver, si te han pillado, te han pillado.Ya nos inventaremos la manera de arreglarlo y que no afecte al grupo. Pero al menos a nosotros no nos mientas.
-Ryo: Se dice que sois solo amigos, como se ha hecho siempre en la Johnnys. No pasará nada.
Subaru sigue sin abrir la boca, está dándole tantas
vueltas al asunto que parece que le fuera a salir humo por las orejas y la
cabeza le fuera a explotar.
-Yasu: A mí me parece mal que tengan que ocultar su
amor, si están liados lo asumiremos. Además yo noto aquí mucha tensión sexual
entre ellos -dice haciendo muchos gestos con las manos, como si fuera todo muy
místico. -Zel: ¡arigatou! Me alegra que lo comprendáis tan bien -hace una reverencia muy grande.
-Yoko: PERO QUE NO ESTAMOS LIADOS. Y COMO TARDE MUCHO EN DESMENTIRLO ENCIMA MI CARRERA SE VA A IR A LA MIERDA Y VOLVERÉ A SER POBRE. LAS FANS DEJARÁ DEAPOYARME SI PIENSAN QUE SOY GAY -grita muy preocupado.
-Yasu: Todo lo contario, ¿aún no te has enterado? -se saca el móvil del bolsillo del pantalón -¡Mirad!
Yasu les enseña las tendencias de Twitter, el hastag #ヨコゼル (#YokoZel) es el
2º más popular en el trending topic japonés de ese día.
-Yoko: ¿LA GENTE ESTÁ SHIPPEANDO ESTA MIERDA?
-Pregunta asombrado y un tanto avergonzado.
Subaru se está poniendo celoso por momentos. Su cara
cada vez tiene peor pinta. Por su parte Zel ve que la broma se le está yendo de
las manos, nunca pensó que el resto de eito aceptaran tan rápido la supuesta
homosexualidad de Yoko (bueno, que tienen a Yasu y a Maru, ya están
acostumbrados...), pero aún menos que las fans aceptaran e incluso apoyaran
"la relación" tan pronto.
-Ryo: ¿Es la 2ª tendencia en Japón? ¿cuál es la
primera?
-Okura (mirando el twitter en su móvil distraídamente): Soy yo... otra vez -comenta muy poco sorprendido.
-Yoko: Joder, para una vez que soy trendic topic, y ni siquiera puedo estar en el primer puesto -suelta cabreado.-¡Solo quiero ser popular!
-Okura: ¿Qué puedo decir? Tengo muchas fans...-añade con voz ultra grave y masculina.
-Yasu: Que síii, que ya lo sabemos, Tacchon. Pero ahora eso no es importante. Mirad, si la gente está shippeando esto, podemos aprovecharnos de ello para vender aún más.-Dice muy exaltado.
-Hina: Pos eso tá mu bien, me gusta.
-Yoko: ¿Aprovecharnos cómo? Yasu, me das miedo.
-Yasu: El member ai vende muy bien. Normalmente es entre miembros del mismo grupo, pero esto puede ser una mina de oro, y muy beneficioso para ambos grupos. Si habéis llegado a trending topic en solo un día, ¿qué no podríais conseguir con más tiempo?
-Okura (mirando el twitter en su móvil distraídamente): Soy yo... otra vez -comenta muy poco sorprendido.
-Yoko: Joder, para una vez que soy trendic topic, y ni siquiera puedo estar en el primer puesto -suelta cabreado.-¡Solo quiero ser popular!
-Okura: ¿Qué puedo decir? Tengo muchas fans...-añade con voz ultra grave y masculina.
-Yasu: Que síii, que ya lo sabemos, Tacchon. Pero ahora eso no es importante. Mirad, si la gente está shippeando esto, podemos aprovecharnos de ello para vender aún más.-Dice muy exaltado.
-Hina: Pos eso tá mu bien, me gusta.
-Yoko: ¿Aprovecharnos cómo? Yasu, me das miedo.
-Yasu: El member ai vende muy bien. Normalmente es entre miembros del mismo grupo, pero esto puede ser una mina de oro, y muy beneficioso para ambos grupos. Si habéis llegado a trending topic en solo un día, ¿qué no podríais conseguir con más tiempo?
Zel asiente con la cabeza, está intentando no salirse
del papel por el momento, pero en realidad no tiene ni puñeteras ganas de
seguir con esa farsa ni dejarse ver con Yoko para vender más, ¡si ni siquiera
le cae bien!
-Hina: A mí me parece güena idea, todo lo que sea más
okane pala mí, siempre es aceptable.
-Yasu: Esto es un hito histórico, las fans de la Johnnys no shippeaban tanto una pareja mezcla de dos grupos desde que Kamenashi y Yamapi hicieron el dorama ese de los colegiales.
-Yoko: No pienso ponerme un uniforme de estudiante, por si ibas a sugerirlo.- Rechaza rotundamente.
-Zel: Pues es una pena, porque el gakuran te sienta de muerte.-le dice pícaramente mientras le toca el brazo desnudo.
-Yasu: Esto es un hito histórico, las fans de la Johnnys no shippeaban tanto una pareja mezcla de dos grupos desde que Kamenashi y Yamapi hicieron el dorama ese de los colegiales.
-Yoko: No pienso ponerme un uniforme de estudiante, por si ibas a sugerirlo.- Rechaza rotundamente.
-Zel: Pues es una pena, porque el gakuran te sienta de muerte.-le dice pícaramente mientras le toca el brazo desnudo.
-Yasu: ¡¡¡KYAAA!!!
Maruyama deja POR FIN de hacer flexiones y observa
interesado.
-Zel: No huyas de mí, tonto, si ahora ya lo saben
todos...-se va acercando a él al mismo tiempo que Yoko retrocede asustado hasta
que se topa con la pared. Mira a Zel con cara de pánico. Ella se pone delante
de él y posa la mano violentamente en la pared haciéndole un kabedon muy de
dorama. Yoko comienza a temblar entre espantado y avergonzado. La cosa es
surrealista, porque para colmo Yoko le saca a Zel más de una cabeza de altura.
Yasu parece tan feliz y emocionado que casi tiene los
ojos en blanco. A Ryo le encanta ver a Yoko pasándolo mal para variar y se
pasea por allí contemplando la escena, hace rato que ha prendido un cigarrillo haciendo caso omiso a la prohibición de fumar dentro del edificio.
Subaru cada vez está más indignado, no ha dicho una maldita palabra en todo el
rato. No hace falta decir que la idea de aprovecharse del shippeo Yokozel le
hace cabrearse infinitamente y no quiere volver a oír hablar de ello nunca más.
Él solo consiguió que las fans gritaran cuando le dio un beso en la mejilla a
Zel en el anterior programa en el que coincidieron, pero ni un triste hastag de
reconocimimiento en las redes apoyándole en su "amor inter-grupos". En
su interior se opone firmemente al Yokozel y a sacar provecho de ello, y tan
pronto como aclare sus ideas se lo hará saber al resto, pero primero tiene
interés en saber qué mierdas pasa entre Yoko y "su" Zelgadiss.
-Yoko: Déjame, ya basta, kudasai... -implora con voz
temblorosa.-Zel: Dime Kimi-kun, ¿te pondrás un gakuran para mí? -le acaricia el cuello - Te queda muy kakkoii el color negro, con esta piel tan blanca.
Yoko se está medio escurriendo hacia abajo por la
pared, parece que quisiera desaparecer. Está colorado y con muy mala cara. Hina
ya no puede contenerse más y tiene una sonrisita en los labios, le gusta ver
por fin a Yoko probando un poco de su propia medicina.
-Yoko: Déjame en paz, anoche te prometí una cosa... y
soy un hombre de palabra...pero... si sigues... se lo contaré -amenaza más
aterrorizado que otra cosa.
-Zel: No vas a decir nada -le posa el dedo en los labios -Shhhhh, el senpai va a estar calladito, ¿deshou?
-Yasu: ¡Esto es mucho mejor que el último yaoi que leí! -grita sobreexcitado.
-Hina: ¿Lees eso? ¡No lo sabía! Pelo si nos dijistle que el polno no te gustaba -Exclama bastante asombrado.
-Yasu: El yaoi no es porno, ¿eh? -dice ofendido.- Es muy bonito.
-Maru: ¡Huy que no! Yasu, te han pillado.
-Okura: El que va de niño inocente... ¡Menuda pieza! Jajajaja -se ríe con sus atronadoras carcajadas.
-Yasu: Oye, que yo soy un chico bueno. ¡Los guarrones sois vosotros!
-Zel: No vas a decir nada -le posa el dedo en los labios -Shhhhh, el senpai va a estar calladito, ¿deshou?
-Yasu: ¡Esto es mucho mejor que el último yaoi que leí! -grita sobreexcitado.
-Hina: ¿Lees eso? ¡No lo sabía! Pelo si nos dijistle que el polno no te gustaba -Exclama bastante asombrado.
-Yasu: El yaoi no es porno, ¿eh? -dice ofendido.- Es muy bonito.
-Maru: ¡Huy que no! Yasu, te han pillado.
-Okura: El que va de niño inocente... ¡Menuda pieza! Jajajaja -se ríe con sus atronadoras carcajadas.
-Yasu: Oye, que yo soy un chico bueno. ¡Los guarrones sois vosotros!
Zel ha aprovechado que el resto están distraídos hablando
sobre la afición "fujoshi" de Yasu para toquetear un poco más a
Yokoyama descamisado y hacerle sufrir. El pobre tiene una cara que parece que
hasta quiera llorar, se siente invadido y casi violado.
-Yoko: Ya no más... lo diré. -Reúne todas las fuerzas
que le quedan para seguir hablando. -Zel-kun es...
Ryo, que era el único atento a la extraña pareja,
empuja a Zelgadiss con fuerza, esta choca contra Yoko con tan mala suerte que
de paso su boca va a parar a la de Kimitaka. Los dos tienen los ojos muy
abiertos por el susto tan grande del accidentado e inesperado "beso".
Se quedan quietos sin reaccionar, parece que ni respiran, son un par de
estatuas de mármol (sobre todo por lo blancos) :p
-Yasu: Creo que me voy a desmayar -se pone la mano en
la frente de manera sobreactuada.
Todos los demás están en silencio. Subaru con la boca
abierta como un buzón, pero sin capacidad de articular palabra. La puerta suena
dos veces "toc, toc". Y sin esperar respuesta, se abre. Las figuras de
Massu, Tegoshi y Ohno aparecen de pronto.
-Tegoshi: ¡JODER, PERO SI ANTES NOS DIJO QUE LO DE LAS FOTOS ERA MENTIRA!
Massu está demasiado avergonzado para decir nada,
nunca se había sentido tan mal por haber "interrumpido" algo. Se tapa
la cara con las manos como si fuera un niño viendo algo prohibido para él.
-Massu: ¡MIS OJOS, MIS OJOOOOS!!!
-Massu: ¡MIS OJOS, MIS OJOOOOS!!!
-Ohno: ¿Truchita? -Pregunta incrédulo.
Zelgadiss reconoce la voz de Satoshi al instante, pero
una extraña fuerza más allá de la física le impide despegarse de los labios de
Yoko.
-Zel: ¿MmmmmMMH?
-Yoko (contestando): Um Mmm mmMmh...
-Maru: Ay madre... la que se va a liar -mira a un lado y a otro como si estuviera en un partido de tenis.
-Yasu: Ahora se está poniendo aún más interesante.
-Yoko (contestando): Um Mmm mmMmh...
-Maru: Ay madre... la que se va a liar -mira a un lado y a otro como si estuviera en un partido de tenis.
-Yasu: Ahora se está poniendo aún más interesante.
Hina le da un tortazo a Yasu porque no le parece bien
que disfrute con el lío que se está montando.
A Ryo se le ha borrado la sonrisa de un plumazo, la ha
cagado pero bien. Subaru es el primero en irse de allí. Pero no si antes
gritarles cuatro cosas.
-Subaru: NO ME LO PUEDO CREER, YOKOYAMA-SAN, YA NO LE VUELVO A HABLAR NUNCA MÁS. USTED HA MUERTO PARA MÍ.-dice inesperadamente en keigo, como si Yoko fuera un completo desconocido. Se larga corriendo con una cara que daría un susto al miedo, y de la que sale empuja a Ohno, que se había quedado como un pasmarote sin reaccionar, Masu y Tego sí se apartan para que pase.
-Ohno: ¡YO SÍ QUE NO ME LO CREO! Pensé que lo que dijeron esta mañana en la televisión tenía que ser algún tipo de confusión, pero después de esto no hay duda. ¿Y andaba preocupado por Subaru? Que tonto he sido... Me voy para que puedas seguir besándote con Yoko, hemos terminado.
-Zel: ¡¡MMMMMMMMMMmmmmmmmmmhhh!! -exclama sin poder apartarse aún de Yoko.
-Hina: ¡ESPELA SATOSHI, QUE NO ES LO QUE TE PIENSAS! -Le grita mientras se va, pero este hace caso omiso y sigue caminando con paso rápido por el pasillo.
-Subaru: NO ME LO PUEDO CREER, YOKOYAMA-SAN, YA NO LE VUELVO A HABLAR NUNCA MÁS. USTED HA MUERTO PARA MÍ.-dice inesperadamente en keigo, como si Yoko fuera un completo desconocido. Se larga corriendo con una cara que daría un susto al miedo, y de la que sale empuja a Ohno, que se había quedado como un pasmarote sin reaccionar, Masu y Tego sí se apartan para que pase.
-Ohno: ¡YO SÍ QUE NO ME LO CREO! Pensé que lo que dijeron esta mañana en la televisión tenía que ser algún tipo de confusión, pero después de esto no hay duda. ¿Y andaba preocupado por Subaru? Que tonto he sido... Me voy para que puedas seguir besándote con Yoko, hemos terminado.
-Zel: ¡¡MMMMMMMMMMmmmmmmmmmhhh!! -exclama sin poder apartarse aún de Yoko.
-Hina: ¡ESPELA SATOSHI, QUE NO ES LO QUE TE PIENSAS! -Le grita mientras se va, pero este hace caso omiso y sigue caminando con paso rápido por el pasillo.
Zel se agarra con todas sus fuerzas a los hombros de
Yoko y empuja haciendo palanca. Por fin, tras unos segundos de forcejeo se
escucha un extraño sonido de succión un "PLOP" como de abrir un bote
embasado al vacío y se consiguen separar. Ambos respiran aliviados.
-Zel: ¡Ha sido justo como en mi pesadilla! -reconoce
de pronto poniéndose un poco colorada.- Luego te veo "labios
ardientes".
Yoko se queda con la boca abierta, totalmente
desencajado, como si necesitara aún algo de tiempo para procesar todos los
acontecimientos que han sucedido en los últimos cinco minutos. Zelgadiss sale
corriendo detrás de Ohno. El pobre Murakami no sabe muy bien qué va a pasar,
así que tras pensarlo un momento y soltar un "dou shiou..." en voz
alta, persigue a su compañero de piso por si necesita de su ayuda (ni siquiera
se viste, va descamisado tal y como estaba). Zelgadiss corre por varios
pasillos en dirección al ascensor, cuando por fin llega, jadeando y con la
cabeza dándole vueltas solo acierta a decir.
-Zel: Satoshi, no podemos romper por esto, no es lo
que crees.
-Satoshi (esperando el ascensor con cara de mala leche): Me prometiste que no te ibas a volver a liar con Shibutani, pero claro, ya veo que tenías a otro kinki diferente en mente.
-Zel: Déjame que te lo explique, con Yoko no hay nada, me da asco solo que lo pienses -pone cara de horror.
-Satoshi: Ya, pues para darte tanto asco, no te he visto con muchas ganas de apartarte de él.
-Zel: Quería, pero no podía...-se justifica mientras se rasca la cabeza sin comprender muy bien lo que pasaba.
-Satoshi: Entonces es peor de lo que pensaba, ¡Eso es que te has enamorado de él! Qué decepción más grande, no me esperaba esto de ti...-dice sin mirarle siquiera a la cara.-Con todas las veces que te he visto insultarle y reírte de él.
-Zel: ¿Enamorarme de Yokoyama-senpai? Jajajajaja -de pronto se le escapa un poco la risa, tal vez por los nervios del momento- Gomen, gomen, no debo reírme de esto. Satoshi, todo esto ha sido solo una broma.
-Satoshi: ¿Una broma? Pues yo no le veo la maldita gracia...-le da al botón del ascensor varias veces- Joder, ¿por qué tarda tanto en subir este cacharro?
-Satoshi (esperando el ascensor con cara de mala leche): Me prometiste que no te ibas a volver a liar con Shibutani, pero claro, ya veo que tenías a otro kinki diferente en mente.
-Zel: Déjame que te lo explique, con Yoko no hay nada, me da asco solo que lo pienses -pone cara de horror.
-Satoshi: Ya, pues para darte tanto asco, no te he visto con muchas ganas de apartarte de él.
-Zel: Quería, pero no podía...-se justifica mientras se rasca la cabeza sin comprender muy bien lo que pasaba.
-Satoshi: Entonces es peor de lo que pensaba, ¡Eso es que te has enamorado de él! Qué decepción más grande, no me esperaba esto de ti...-dice sin mirarle siquiera a la cara.-Con todas las veces que te he visto insultarle y reírte de él.
-Zel: ¿Enamorarme de Yokoyama-senpai? Jajajajaja -de pronto se le escapa un poco la risa, tal vez por los nervios del momento- Gomen, gomen, no debo reírme de esto. Satoshi, todo esto ha sido solo una broma.
-Satoshi: ¿Una broma? Pues yo no le veo la maldita gracia...-le da al botón del ascensor varias veces- Joder, ¿por qué tarda tanto en subir este cacharro?
Murakami aparece caminando con paso rápido.
-Hina: ¡Pol fin os encuentlo! jopetas, no os había
veido hacía donde corríais... Satoshi, no te enfades con Zel, esto ha sido
culpa mía, quelía reilme de Yoko y gastale una bloma pala puteale un poco...
Zel me quiso de ayudal polque soy su "muy mejol amigo".
-Satoshi: Ya, y tan "amigos" que sois, que por lo visto hasta dormís juntos...
-Satoshi: Ya, y tan "amigos" que sois, que por lo visto hasta dormís juntos...
Hina y Zel cruzan sus miradas un segundo, lo justo
para comprender que esto NO está yendo bien.
-Hina y Zel (hablando atropelladamente a la vez):
¡¡No, no nooo, nada de eso, es una confusión!!
-Zel: Entonces... ¿viste ayer el music station? -dice cambiando un poco de tema.
-Ohno: Al menos no te equivocaste cantando...
-Zel: ¿Te gustó mi actuación? -se acerca y le agarra la mano mientras pone cara de gatito kawaii.
-Ohno (apartando su mano para que Zel le suelte): Cantaste bien, lo que no me gustó fue que Subaru te abrazara... ni que duermas con este tío.

-Zel: Entonces... ¿viste ayer el music station? -dice cambiando un poco de tema.
-Ohno: Al menos no te equivocaste cantando...
-Zel: ¿Te gustó mi actuación? -se acerca y le agarra la mano mientras pone cara de gatito kawaii.
-Ohno (apartando su mano para que Zel le suelte): Cantaste bien, lo que no me gustó fue que Subaru te abrazara... ni que duermas con este tío.

Satoshi mira a Hina durante unos segundos con muy mala
leche. Murakami está con su cara de susto de que "no había papel", le
falta capacidad de reacción al pobre.
-Hina: No dolmimos juntos, es que me expliqué mu
malamente en el poglama -dice avergonzado.- No te pienses cosas que no son,
Ohno. Y lo de Yoko ha sido una bloma, de veldá. Si cleo que a Zel hasta le da
miedo Yoko, siemple que viene pol casa, Zel se va coliendo de allí como un neko
asustao.
Zelgadiss asiente varias veces a lo que ha dicho Hina.
-Satoshi: ¿Y es necesario que Zel se tenga que besar con Yokoyama para la broma? -pregunta un poco menos encabronado- ¿Y lo de anoche qué demonios significa? Todas las televisiones andan poniendo papapics vuestras y diciendo que andáis liados en secreto. ¿Cómo se supone que debo tomármelo?
-Zel: Lo de anoche no formaba parte de la broma. Estaba en casa después de la actuación cuando Yoko me llamó para que nos reuniéramos en Shibuya.
-Ohno: ¿Y por qué vas tan tarde allí? ¿Y si te pasa algo?
-Hina: Eso mismo le he dicido yo, pelo nunca me hase caso, encima que luego no había tlenes y se tuvo que volvel a casa en el taxi -dice en plan paternalista. -Que pol sielto, le plesté 3mil yenes, que no sé quién me los va a devolvel...
-Zel: Joooder... cuando cobre te los devuelvo -contesta a Hina.- Satoshi yo también tenía miedo de ir, pero no porque me pasara algo, si a mí el que más miedo me da es Yokoyama.
-Yoko (mientras dobla la esquina del pasillo, al menos él SÍ viene vestido): ¿Ah sí, te doy miedo? Pues hace un momento no te he visto que te temblara la mano precisamente para tocarme hasta el trasero, encima delante de mi grupo, no he pasado más vergüenza en mi puñetera vida. Seguro que van a estar vacilándome con esto durante años. ¡Y para colmo vas y me besas! ¡NO TIENES DECENCIA!
-Zel: ¡YO NO LE HE BESADO, ALGO ME EMPUJÓ HACIA USTED!
-Ohno: ¿El amor? -pregunta confuso.
-Zel: ¡Que no!, ¿cómo va a ser eso?
-Hina: ¿Qué amol? Fue Ryo-chan que le vi yo. Yoko iba a dicil algo cuando Ryo de pronto empujó a Zel contra él. Palecía mu nelvioso. A mí me faltan datos, pelo espelo que ninguno de vosotros esté metido en asuntos de dlogas ni tengáis tlatos con la mafia china, ya quedáis avisaos! -les amenaza.
-Satoshi: ¿Y es necesario que Zel se tenga que besar con Yokoyama para la broma? -pregunta un poco menos encabronado- ¿Y lo de anoche qué demonios significa? Todas las televisiones andan poniendo papapics vuestras y diciendo que andáis liados en secreto. ¿Cómo se supone que debo tomármelo?
-Zel: Lo de anoche no formaba parte de la broma. Estaba en casa después de la actuación cuando Yoko me llamó para que nos reuniéramos en Shibuya.
-Ohno: ¿Y por qué vas tan tarde allí? ¿Y si te pasa algo?
-Hina: Eso mismo le he dicido yo, pelo nunca me hase caso, encima que luego no había tlenes y se tuvo que volvel a casa en el taxi -dice en plan paternalista. -Que pol sielto, le plesté 3mil yenes, que no sé quién me los va a devolvel...
-Zel: Joooder... cuando cobre te los devuelvo -contesta a Hina.- Satoshi yo también tenía miedo de ir, pero no porque me pasara algo, si a mí el que más miedo me da es Yokoyama.
-Yoko (mientras dobla la esquina del pasillo, al menos él SÍ viene vestido): ¿Ah sí, te doy miedo? Pues hace un momento no te he visto que te temblara la mano precisamente para tocarme hasta el trasero, encima delante de mi grupo, no he pasado más vergüenza en mi puñetera vida. Seguro que van a estar vacilándome con esto durante años. ¡Y para colmo vas y me besas! ¡NO TIENES DECENCIA!
-Zel: ¡YO NO LE HE BESADO, ALGO ME EMPUJÓ HACIA USTED!
-Ohno: ¿El amor? -pregunta confuso.
-Zel: ¡Que no!, ¿cómo va a ser eso?
-Hina: ¿Qué amol? Fue Ryo-chan que le vi yo. Yoko iba a dicil algo cuando Ryo de pronto empujó a Zel contra él. Palecía mu nelvioso. A mí me faltan datos, pelo espelo que ninguno de vosotros esté metido en asuntos de dlogas ni tengáis tlatos con la mafia china, ya quedáis avisaos! -les amenaza.

Ohno, Zel y Yoko no ven la relación de lo que dice Hina ahora de drogas ni chinos a cuento de nada, le miran con cara de extrañeza.
-Yoko: Shingo... por qué no vas a buscar a Subaru, que
se fue corriendo y a saber dónde se ha metido. Y le traes de vuelta al cuarto
de ensayos, porque como se haya puesto cabezota no va a ser fácil. Será mejor
que lleves su medicación de los nervios por si acaso.
-Hina: ¿Y pol qué tengo que il yo? ¿Qué pasa, acaso soy su niñela?
-Yoko: Sí, lo eres, de hecho hasta lo pone en tu contrato, eso y lo de que tienes que limpiarle los mocos a Ryo.
-Hina: ¡Ay, pos es veldá! Me s'abía olvidao...Voy a vel si le encuentlo. Zel-kun, si pasa algo me llamas al móvil, que yo te defiendo de estos dos. Si hace falta pegales en su cabeza también puedo vinil, ¿naaa?
-Zel: Gracias Hina, eres mi "muy mejor amigo". Pero creo que no te necesito por ahora. ¡Mata ne!
-Hina: ¿Y pol qué tengo que il yo? ¿Qué pasa, acaso soy su niñela?
-Yoko: Sí, lo eres, de hecho hasta lo pone en tu contrato, eso y lo de que tienes que limpiarle los mocos a Ryo.
-Hina: ¡Ay, pos es veldá! Me s'abía olvidao...Voy a vel si le encuentlo. Zel-kun, si pasa algo me llamas al móvil, que yo te defiendo de estos dos. Si hace falta pegales en su cabeza también puedo vinil, ¿naaa?
-Zel: Gracias Hina, eres mi "muy mejor amigo". Pero creo que no te necesito por ahora. ¡Mata ne!
Hina se va con paso rápido mientras se le oye
farfullar "¿adonde estalá el Shibuyan?"
-Yoko: Bueno, ahora que Hina se ha ido... -Agarra a
Zel de los brazos y la empuja con fuerza contra la pared como poseído por
alguno de sus personajes malvados de dorama.-¿Me puedes explicar qué demonios
significaba el teatrillo de antes?
-Zel: ¡Itai! Significar nada, solo que Shingo y yo queríamos reírnos de ti -confiesa aterrada.
-Zel: ¡Itai! Significar nada, solo que Shingo y yo queríamos reírnos de ti -confiesa aterrada.
Ohno les mira con cara de susto, pero no dice nada.
Vuelve a apretar el botón del ascensor, si a estas alturas y viendo que no
funciona, no se ha ido por las escaleras, es porque en el fondo quiere quedarse
allí.
-Yoko (hablándole muy cerca):¡¿Cómo?! ¡¿Que Shingo
también está metido en esto?! ¡Eso sí que no me lo imaginaba! Pensé que todo
era obra tuya, que eres una chica muy mala. Ups...Ohno sabe que eres una chica,
¿no?
-Zel: Por supuesto, Ohno es mi novio -contesta mientras con la manga de la sudadera se limpia de la cara un salivazo que le ha tirado Yoko con sus gritos.
-Ohno: Ex-novio-puntualiza.
-Zel: Por supuesto, Ohno es mi novio -contesta mientras con la manga de la sudadera se limpia de la cara un salivazo que le ha tirado Yoko con sus gritos.
-Ohno: Ex-novio-puntualiza.
Zel pone cara de angustia, pero no le dura mucho
porque Yoko vuelve a empujarle contra la pared.
-Yoko: Hina y tú me las vais a pagar, de eso ya me encargo yo. Nadie me avergüenza de esa manera y queda impune, ¿entiendes?
-Zel: Senpai, me está dando mucho miedo...-dice con un hilo de voz.
-Ohno (interrumpiendo por fin): Perdona, ¿te importaría dejar de asustar a mi novia?
-Yoko: ¿Pero no era tu ex? -pregunta confundido.
-Ohno: Bueno, cuando me contéis lo del love hotel de anoche decidiré si es mi novia o mi ex.
-Zel: Pues en ese caso sigo siendo tu novia, porque no pasó nada.
-Yoko: No pasó nada excepto que "tu novia" es completamente baka y para despistar a un paparazzi no se le ocurre nada mejor que meterse en un love hotel. Es que ni leyó el cartel, solo se fijó en que las luces eran bonitas. Si yo fuera tú rompería con ella, es una chica muy tonta.
-Zel: Yo no soy tonta, en primer lugar es todo culpa suya. Me llamó para chantajearme.
-Ohno: No te preocupes, ya sé que te atraen las luces y los colores, no eres baka por eso -le acaricia la cabeza a Zel.- Un momento ¿Qué es eso del chantaje?
-Yoko: Es un asunto entre nosotros, no te incumbe -contesta cortantemente.
-Ohno: Eso lo decidiré yo. ¿Zel, qué ocurre?¿Qué movidas tienes con este kinki?
-Zel: Bueno... pues... que me ha dicho que tengo que ir a limpiar su casa una vez a la semana o dirá a los medios de comunicación que soy una chica y me echarán de la Johnnys...Bueno, y del país.
-Ohno: ¡Y una mierda, tú no vas a decir nada, Yokoyama! -Le grita cabreado.
-Yoko: Si Zel cumple su parte del trato, no diré nada, tranquilo.
-Ohno: Eres un aprovechado, como senpai tuyo te pido que retires el chantaje.
-Yoko: Este es un asunto entre Zel y yo, y como soy más senpai que Zel tendrá que hacer lo que yo diga.
-Ohno: Ya, pero yo soy más Senpai que tú y te digo que lo del chantaje se ha acabado. Además a ver qué mierda vais a hacer ahora para arreglar lo del escándalo, están diciendo que sois amantes secretos en todas partes.
-Yoko: Bueno, pues si lo dicen en todos lados ya no es "secreto" -dice comentando algo obvio.
-Zel: Yasu dijo que podemos aprovecharlo para vender más. La fans lo están shippeando en internet.
-Ohno: ¿QUE LO ESTÁN SHIPPEANDO? Joder, esto se nos escapa de las manos...-se rasca la frente preocupado.
-Yoko: Y tanto que se nos escapa. Me da igual lo que diga Yasu, yo no quiero tener que andar saliendo contigo por ahí para promocionarnos. Lo que me faltaba.
-Zel: Senpai, a ver si se piensa que yo quiero que me vean con usted. Mire lo de anoche... ¿se cree que no me da vergüenza que digan que somos amantes? ¡Kimochi warui!
-Yoko: ¡Tú sí que me das asco, chico travesti! -exclama ofendido.
-Ohno: Oye, no le digas cosas feas a mi novia.
-Zel: ¿Aún seguimos siendo novios?-pregunta emocionada.-Se acerca a acariciar la cara de pantorta de Satoshi.
-Ohno: Si tú aún quieres serlo, claro...porque la otra noche yo también me comporté mal cuando fui a casa de Hina, y después cuando te llamé todo borracho mientras estaba con Subaru... Dije cosas muy estúpidas y eso que no me acuerdo bien de todo, había bebido demasiado.
-Zel: Me hiciste llorar, Satoshi-kun.
-Ohno: Gomen ne, truchita -dice mirando fijamente a Zelgadiss, le da un pellizo cariñoso en la cara- Si me prometes que no me vas a engañar con nadie, te juro que te creeré de ahora en adelante. Y no haré más caso a las mierdas que me diga Subaru, ni tampoco a las fotos de las revistas de cotilleos.
-Zel: Shibutani-san solo quiere que nos enfademos entre nosotros, no le tienes que escuchar. No te voy a engañar, Satoshi, con lo que yo te quiero -Le pone la mano en el hombro.- Si alguna vez me gusta otra persona te lo diré, pero no voy a mentirte ni a andarme con engaños. ¿Yakusoku?
-Ohno: Bien, yakusoku -alza su dedo meñique y Zel entrelaza el suyo con el del hastercito.
Yokoyama está visiblemente incómodo con tanto amor y
reconciliaciones delante de su cara, podría vomitar arcoiris por la pastelada
que tiene ahí. Mira a otro lado para disimular.
-Zel: ¿Me das un beso?
-Ohno: ¡Sí! -se acerca para besarla, pero de pronto se frena como dándose cuenta de algo.- No, sería como dar un beso indirecto a Yokoyama.
-Yoko: Anda este, ¿y qué tengo de malo? Me estáis ofendiendo mucho entre los dos -se cruza de brazos herido en su orgullo.
-Ohno: hombre "malo" no tienes nada, pero no me apetece besar a Zel cuando te ha besado a ti antes.
-Yoko: Pues que sepas que muchas fans matarían por poder besarme.
-Zel: ¡Puag! Que mal gusto.
-Yoko: Calla baka, que tú no entiendes nada. Soy bastante popular.
-Zel: ¿Me das un beso?
-Ohno: ¡Sí! -se acerca para besarla, pero de pronto se frena como dándose cuenta de algo.- No, sería como dar un beso indirecto a Yokoyama.
-Yoko: Anda este, ¿y qué tengo de malo? Me estáis ofendiendo mucho entre los dos -se cruza de brazos herido en su orgullo.
-Ohno: hombre "malo" no tienes nada, pero no me apetece besar a Zel cuando te ha besado a ti antes.
-Yoko: Pues que sepas que muchas fans matarían por poder besarme.
-Zel: ¡Puag! Que mal gusto.
-Yoko: Calla baka, que tú no entiendes nada. Soy bastante popular.
Zelgadiss pasa de Yoko y pone cara de tristeza, se ha
quedado sin su beso de hamstercito, encima de que hace tanto tiempo que Ohno y
ella no hacen nada de nada...
-Zel: Jo... yo quería un beso.
-Yoko: ¡A la mierda! Pues a ver si te apetece más después de esto -se acerca de pronto a Ohno, le agarra por la barbilla y le da un pico.
-Zel (en modo Yasu-Fujoshi): ¡YABAI!
-Zel: Jo... yo quería un beso.
-Yoko: ¡A la mierda! Pues a ver si te apetece más después de esto -se acerca de pronto a Ohno, le agarra por la barbilla y le da un pico.
-Zel (en modo Yasu-Fujoshi): ¡YABAI!
Se aparta de él y le mira con arrogancia.
-Zel: ¡UNA FOTO, UNA FOTO! -Grita como una fan loca.
Yoko y Ohno posan.-Ohno: Yawarakai...-dice refiriéndose a los labios de Yoko.
-Yoko: Sí, lo sé, me lo dicen mucho -sigue con una expresión altiva en el rostro.
-Ohno: Oye Zel... ¿a ti te ha gustado cuando os habéis besado antes?
-Zel: ¿Quéeee? Noooo, nada de eso -contesta mirando al suelo avergonzada.-¿Por qué lo preguntas ? ¿A ti te ha gustado besarle?
-Ohno: ¡No, no, no! Para nada -dice sofocado mintiendo de mala manera.
-Yoko: Os ha gustado a los dos, no lo neguéis ahora.-exclama cansado de tanta palabrería. -Venga callad y besaos de una maldita vez. Ahora estáis iguales, os he besado a ambos.
Zel y Satoshi se miran con ojos tiernos.
-Ohno: Ven aquí truchita -Le dice antes de rodearla
con su brazo y empezar a besarla.
Yoko se saca el móvil del bolsillo y entra en Twitter,
busca el escándalo y ahora ya son el primer puesto en el trending topic japonés.
Han conseguido desbancar a Okura y su atractivo con su historia de falso amor
homogayer. Le cabrea la situación, pero extrañamente se siente orgulloso de
haber llegado a tener el hastag más popular del día, observa los retwets con
una mueca sombría en la cara, las fans locas hasta han escaneado la revista
para compartirla. Después mira a Zel y Ohno, lo que se supone que tenía que ser
un beso de reconciliación va a acabar convirtiéndose en un polvo en un pasillo
como alguien no los pare rápido. Ohno está sobando el trasero de Zel mientras
se besan y Zelgadiss tiene una mano metida por debajo de la camisa de Satoshi
mientras con la otra intenta desabrocharle los botones, o arrancárselos
directamente.
-Yoko: ¡Oiiiii, vosotros dos! Ya basta. -Les grita.
Se apartan un poco, visiblemente acalorados.
-Zel: Espera, solo un poquito más -dice agarrando a
Satoshi del cuello para volver a besarle.
-Yoko: ¡OMAE, YAMETEKURRRE! -grita cabreado con mucho acento de Osaka.- ¿Voy a tener que ir a buscar un palo para separaros? Zel, tienes que ensayar, ¿me equivoco?
-Zel: Tiene razón, senpai, pero es que hace tanto tiempo que Ohno y yo no...
-Yoko: Sí, lo que sea, no me interesa -le corta bordemente.- Y tú Ohno, ¿no tienes cosas que hacer?
-Ohno: Huy, lo había olvidado, si precisamente a lo que yo había venido hoy era a contarte una cosa, truchita.
-Zel: ¿A mí?
-Ohno: Sí, fui a donde se supone que estabas con Los Tegomassu, pero me dijeron que habías ido a hablar un momento con Murakami. Así que los tres fuimos a buscarte.
-Zel: Ahh, claro, ahora todo tiene sentido.
-Ohno: Y entonces te encontramos... ejem...
-Zel (mirando a Yokoyama de pronto): Senpai, ¿sabe por qué no podía separarme de usted?
-Yoko: Claro que sí, por la atracción tan grande que sientes por mí -contesta haciéndose el kakkoii.
-Zel: ¿ EL QUÉ? -pregunta muy asustada mientras retrocede un paso y pisa sin querer el pie de Satoshi.
-Ohno: ¡Itai!-se queja.
-Yoko: Es coña, jajajajaja. Tranquila, es por la forma de mis labios, a veces hacen ventosa, sobre todo si beso con fuerza y es que tú te echaste sobre mi boca con un ímpetu...
-Zel: Es culpa de Nishikido -dice avergonzada.- Le voy a dar un tortazo en cuanto le vea. No, mejor le diré a Hina que le pegue, tiene más fuerza.
-Yoko: ¡OMAE, YAMETEKURRRE! -grita cabreado con mucho acento de Osaka.- ¿Voy a tener que ir a buscar un palo para separaros? Zel, tienes que ensayar, ¿me equivoco?
-Zel: Tiene razón, senpai, pero es que hace tanto tiempo que Ohno y yo no...
-Yoko: Sí, lo que sea, no me interesa -le corta bordemente.- Y tú Ohno, ¿no tienes cosas que hacer?
-Ohno: Huy, lo había olvidado, si precisamente a lo que yo había venido hoy era a contarte una cosa, truchita.
-Zel: ¿A mí?
-Ohno: Sí, fui a donde se supone que estabas con Los Tegomassu, pero me dijeron que habías ido a hablar un momento con Murakami. Así que los tres fuimos a buscarte.
-Zel: Ahh, claro, ahora todo tiene sentido.
-Ohno: Y entonces te encontramos... ejem...
-Zel (mirando a Yokoyama de pronto): Senpai, ¿sabe por qué no podía separarme de usted?
-Yoko: Claro que sí, por la atracción tan grande que sientes por mí -contesta haciéndose el kakkoii.
-Zel: ¿ EL QUÉ? -pregunta muy asustada mientras retrocede un paso y pisa sin querer el pie de Satoshi.
-Ohno: ¡Itai!-se queja.
-Yoko: Es coña, jajajajaja. Tranquila, es por la forma de mis labios, a veces hacen ventosa, sobre todo si beso con fuerza y es que tú te echaste sobre mi boca con un ímpetu...
-Zel: Es culpa de Nishikido -dice avergonzada.- Le voy a dar un tortazo en cuanto le vea. No, mejor le diré a Hina que le pegue, tiene más fuerza.
Yokoyama asiente porque está de acuerdo con eso, de hecho
tiene ganas de pegarle él también.
-Yoko: Se le podía haber ocurrido otra cosa para que
yo no te descubriera delante del resto.
-Ohno (preocupado): Yokoyama-kun, ¡tienes que mantener el secreto de Zel, kudasai!
-Ohno (preocupado): Yokoyama-kun, ¡tienes que mantener el secreto de Zel, kudasai!
Yoko vuelve a asentir.
-Zel: Por cierto, Satoshi-kun, que es lo tenías que
decirme.
-Ohno: Oh, ¿recuerdas las fotos que me hiciste en España?
-Zel: ¿Cuales, las guarras?
-Ohno: Las "artísticas" - matiza.
-Zel: O sea, las guarras.
-Ohno: Bueno, llámalas como quieras. Te acuerdas que las enviamos a la Anan para ver si colaba y me tenían en cuenta, bueno pues me llamaron ayer para decirme que me iban a sacar en la revista, hoy tengo que ir a hablar de la sesión de fotos. He quedado dentro de un rato. Estoy un poco nervioso.
-Zel: Qué ilusión, vas a salir en la Anan, pues me voy a comprar por lo menos 10, para guardar el reportaje de recuerdo -le sobetea el brazo.
-Yoko: Pues a mí nunca me han sacado en solitario, y menos haciendo posado sexy... ¿para eso me machaco en el gimnasio varios días a la semana? Menuda mierda -Dice con clara envidia.
-Ohno: Bueno, ya te sacarán alguna vez, hombre.
-Yoko: Que va, a los del Kansai no nos quieren en la Anan... bueno, a Okura y Ryo sí -añade con fastidio.
-Zel: Y a Juncihi -dice por joderle más.- Pues si no es en esa ya le sacarán en otra revista, senpai. Con ese careto igual en el national geografic o así -dice con sorna.
- Yoko: ¿EN EL NATIONAL GEOGRAFIC? ¡A QUE TE METO! -levanta la mano para darle una hostia a Zelgadiss.

-Ohno: Oh, ¿recuerdas las fotos que me hiciste en España?
-Zel: ¿Cuales, las guarras?
-Ohno: Las "artísticas" - matiza.
-Zel: O sea, las guarras.
-Ohno: Bueno, llámalas como quieras. Te acuerdas que las enviamos a la Anan para ver si colaba y me tenían en cuenta, bueno pues me llamaron ayer para decirme que me iban a sacar en la revista, hoy tengo que ir a hablar de la sesión de fotos. He quedado dentro de un rato. Estoy un poco nervioso.
-Zel: Qué ilusión, vas a salir en la Anan, pues me voy a comprar por lo menos 10, para guardar el reportaje de recuerdo -le sobetea el brazo.
-Yoko: Pues a mí nunca me han sacado en solitario, y menos haciendo posado sexy... ¿para eso me machaco en el gimnasio varios días a la semana? Menuda mierda -Dice con clara envidia.
-Ohno: Bueno, ya te sacarán alguna vez, hombre.
-Yoko: Que va, a los del Kansai no nos quieren en la Anan... bueno, a Okura y Ryo sí -añade con fastidio.
-Zel: Y a Juncihi -dice por joderle más.- Pues si no es en esa ya le sacarán en otra revista, senpai. Con ese careto igual en el national geografic o así -dice con sorna.
- Yoko: ¿EN EL NATIONAL GEOGRAFIC? ¡A QUE TE METO! -levanta la mano para darle una hostia a Zelgadiss.

Zel se esconde detrás de Ohno mientras se le escapa la
risa.
-Ohno: No seas maleducada, Zelgadiss.
-Zel: Gomen ne, es que vacilar a los senpais es muy divertido.
-Ohno: Pues tienes razón -dice pensando en todas las veces que se la ha liado parda a Nakai en la tele.
-Zel: Gomen ne, es que vacilar a los senpais es muy divertido.
-Ohno: Pues tienes razón -dice pensando en todas las veces que se la ha liado parda a Nakai en la tele.
El ascensor comienza a sonar como si estuviera
subiendo de pronto. Los tres se miran extrañados.
-Yoko: Pero si no funcionaba, ¿na?
Zel se encoge de hombros, ahora tienen
curiosidad. El ascensor para justo en esa planta, la 4ª. Se abre la puerta y
Tsubasa sale como si tal cosa de dentro. Taki está acabando de peinarse
mientras se mira en el espejo que hay en la pared en el ascensor. Sale con paso
rápido.
-Yoko, Zel y Ohno: Otsukaresama desu.
-Tsubasa: Otsukareee.
-Taki: Gokurosama desu.
-Tsubasa: Otsukareee.
-Taki: Gokurosama desu.
Taki se va tan tranquilo por el pasillo,
disimulando como si no hubiera pasado nada. Zel le hace un gesto a Tsubasa para
llamar su atención, luego se señala la bragueta. Tsubasa se mira el pantalón y
ve que la lleva abierta. Se la cierra rápido y se le ve articular un
"grasias" a Zel, luego se lleva el dedo a los labios en un gesto de
"silencio, no digáis nada". Se va rápidamente siguiendo a Takizawa
hacia uno de los cuartos de ensayo.
-Ohno: A mí eso me pasa mucho.
-Yoko: ¿El qué, follar con Tackey en un ascensor?
-Ohno: No, llevar la bragueta abierta... ¿qué? ¿estaban follando ahí dentro? ¿Pero esos dos están liados?
-Zel: Joder Satoshi, no te enteras de nada -le da un beso en la mejilla.
-Yoko: Hay mucha homosexualidad encubierta en la compañía -comenta en voz alta.
-Zel: ¿Lo dice por experiencia propia, senpai? -pregunta a mala leche.
-Yoko: ¡OMAEEE! -grita ofendido y levanta la mano para pegarle, pero Zel se aleja de él rápidamente.
-Zel: Gomen, es entretenido reírme de usted -le sonríe.
-Yoko: ¡Respeta a los senpais!
-Ohno: Hablando de follar, ¿puedes quedar esta tarde a última hora conmigo? Para... bueno, para eso.
-Yoko: Satoshi-kun, eres todo un romántico -dice irónico.
-Zel: Jo, hoy no puedo, tengo mucho lío, tengo que volver al ensayo, y luego a la tarde a casa de Yamapi, a darle clase de inglés y español. Qué poco me apetece ir...
-Yoko: ¿das clases de inglés? Pues podrías enseñarme un poco -dice interesado.
-Zel: Senpai, le he visto en el programa ese que salen con extranjeros, usted no necesita clases de inglés, usted lo que necesita es un milagro.

-Yoko: ¿El qué, follar con Tackey en un ascensor?
-Ohno: No, llevar la bragueta abierta... ¿qué? ¿estaban follando ahí dentro? ¿Pero esos dos están liados?
-Zel: Joder Satoshi, no te enteras de nada -le da un beso en la mejilla.
-Yoko: Hay mucha homosexualidad encubierta en la compañía -comenta en voz alta.
-Zel: ¿Lo dice por experiencia propia, senpai? -pregunta a mala leche.
-Yoko: ¡OMAEEE! -grita ofendido y levanta la mano para pegarle, pero Zel se aleja de él rápidamente.
-Zel: Gomen, es entretenido reírme de usted -le sonríe.
-Yoko: ¡Respeta a los senpais!
-Ohno: Hablando de follar, ¿puedes quedar esta tarde a última hora conmigo? Para... bueno, para eso.
-Yoko: Satoshi-kun, eres todo un romántico -dice irónico.
-Zel: Jo, hoy no puedo, tengo mucho lío, tengo que volver al ensayo, y luego a la tarde a casa de Yamapi, a darle clase de inglés y español. Qué poco me apetece ir...
-Yoko: ¿das clases de inglés? Pues podrías enseñarme un poco -dice interesado.
-Zel: Senpai, le he visto en el programa ese que salen con extranjeros, usted no necesita clases de inglés, usted lo que necesita es un milagro.

A Ohno le da la risa, pero disimula para que
Yoko no se enfade también con él.
-Yoko: Que va,
si yo pillo bastante -dice muy envalentonado.- Hablar mal, pero de lo que me
digas en inglés, entiendo un montón.
Zel le pregunta la hora con perfecto acento Londinense
y Yoko se queda con la boca abierta pensándoselo mucho. No ha entendido ni una
palabra. Ohno que aún ha entendido menos le observa para ver lo que contesta
pensando realmente que Yoko se ha enterado.
-Yoko: Jooo, no vale, esa era a pillar, me has
preguntado algo súper difícil para hacerme quedar mal delante de Ohno.
-Ohno:¿Delante de mí? Si yo no entendí nada -se encoje de hombros.
-Zel: Pues estáis apañados vosotros para viajar al extranjero, no sabéis ni pedir una coca cola en la cafetería.
-Yoko: Por eso el presidente no nos deja hacer giras internacionales, para que no pasemos vergüenza en otros países y quedemos como gilipollas.
-Ohno: Es muy considerado -dice convencido.
-Zel: Ah, entonces era por eso... Pues las fans internacionales lo llevan claro si esperan un tour por allí.
-Ohno:¿Delante de mí? Si yo no entendí nada -se encoje de hombros.
-Zel: Pues estáis apañados vosotros para viajar al extranjero, no sabéis ni pedir una coca cola en la cafetería.
-Yoko: Por eso el presidente no nos deja hacer giras internacionales, para que no pasemos vergüenza en otros países y quedemos como gilipollas.
-Ohno: Es muy considerado -dice convencido.
-Zel: Ah, entonces era por eso... Pues las fans internacionales lo llevan claro si esperan un tour por allí.
Ohno mira el reloj y se da cuenta de que se le está
haciendo tarde, se despide rápidamente de Zel con un besito y se sube al
ascensor aprovechando que ya por fin funciona... Zel y Yoko se despiden de él
agitando la mano mientras la puerta se cierra.
-Ohno: Cuídate el ojo -dice antes de que el ascensor
se ponga en marcha.
Yoko mira a Zel fijamente, de hecho tanto que es como
si le clavara la mirada como un puñal.
-Yoko: De ser tú me cuidaría más las espaldas -dice
otra vez pareciendo un maloso de dorama.
-Zel: ¿Nani? -se asusta.
-Yoko: ¿No creerás en serio que esto se ha acabado aquí?
-Zel: ¿Nani? -se asusta.
-Yoko: ¿No creerás en serio que esto se ha acabado aquí?
CONTINUARÁ.... (dentro de 1 semana) ^_^

















